.. _user-guide:

**********
User Guide
**********
The TorchANI plug-in provides the TorchANI machine-learning models for DFT and
couple-cluster level quantum chemistry calculations. Similar accuracy but much faster!

..
   The following sections cover accessing and controlling this functionality.

   .. toctree::
      :maxdepth: 2
      :titlesonly:

Index
=====

* :ref:`genindex`
